/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.apache.tez.test;

import java.io.IOException;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.yarn.conf.YarnConfiguration;
import org.junit.Assert;
import org.junit.Test;

public class TestMiniTezCluster {

  @Test
  public void testOverrideYarnDiskHealthCheck() throws IOException {
    MiniTezCluster tezMiniCluster = new MiniTezCluster(TestMiniTezCluster.class.getName(), 1, 1, 1);
    tezMiniCluster.init(new Configuration());
    tezMiniCluster.start();

    // overrides if not set
    Assert.assertEquals(99.0, tezMiniCluster.getConfig()
        .getFloat(YarnConfiguration.NM_MAX_PER_DISK_UTILIZATION_PERCENTAGE, -1), 0.00001);

    tezMiniCluster.close();

    tezMiniCluster = new MiniTezCluster(TestMiniTezCluster.class.getName(), 1, 1, 1);
    Configuration conf = new Configuration();
    conf.setFloat(YarnConfiguration.NM_MAX_PER_DISK_UTILIZATION_PERCENTAGE, 50);
    tezMiniCluster.init(conf);
    tezMiniCluster.start();

    // respects provided non-default value
    Assert.assertEquals(50.0, tezMiniCluster.getConfig()
        .getFloat(YarnConfiguration.NM_MAX_PER_DISK_UTILIZATION_PERCENTAGE, -1), 0.00001);

    tezMiniCluster.close();
  }
}
